.. _configuring:

=============================
Tobiko Configuration Options
=============================

This section provides a list of all configuration options for Tobiko.
These are auto-generated from Tobiko code when this documentation is
built.

Configuration Reference
-----------------------

.. toctree::
   :maxdepth: 1

   tobiko.rst

Sample Configuration Files
--------------------------

.. toctree::
   :maxdepth: 1

   samples/tobiko.rst
